#[non_exhaustive]#[repr(i32)]pub enum MdfStorageType {
FixedLengthStorage = 0,
VlsdStorage = 1,
MlsdStorage = 2,
}Expand description
\brief Enumerate that defines how the raw data is stored. By default the fixed length record is stored. Only used when doing bus logging.
The fixed length storage is using one SD-block per byte array. The SD block is temporary stored in primary memory instead of store it on disc. This storage type is not recommended for bus logging.
The variable length storage uses an extra CG-record for byte array data. The storage type is used for bus logging where payload data is more than 8 byte.
The maximum length storage shall be used when payload data is 8 bytes or less. It is typically used when logging CAN messages which have 0-8 data payload.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FixedLengthStorage = 0
< The default is to use fixed length records.
VlsdStorage = 1
< Using variable length storage.
MlsdStorage = 2
< Using maximum length storage