#[non_exhaustive]#[repr(u8)]pub enum ChannelType {
FixedLength = 0,
VariableLength = 1,
Master = 2,
VirtualMaster = 3,
Sync = 4,
MaxLength = 5,
VirtualData = 6,
}Expand description
\brief Channel functional type.
Most channels are marked as ‘FixedLength’ which means that its size in a record is fixed. This works well with most data types but byte arrays and strings may change its size. Instead are these data types marked as ‘Variable Length’. Avoid writing variable length data as it may allocate a lot of memory as it flush at the end of the measurement.
One channel in channel group (IChannelGroup), should be marked as a master channel. This channel is typical relative sample time with seconds as unit. The master channel is typical used on the X-axis when plotting data.
The ‘VirtualMaster’ channel can be used if the sample number is linear related to the sample time. The channel conversion (CC) block should define the sample number to time conversion.
The ‘Sync’ channel is used to synchronize an attachment block (file).
The ‘MaxLength’ type is typical used when storing CAN byte array where another channel stores actual bytes stored in a sample. For CAN the size in the max record size is 8 bytes.
The ‘VirtualData’ is similar to the ‘VirtualMaster’ channel but related to data. Good luck to find a use of this type.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
FixedLength = 0
< Fixed length data (default type)
VariableLength = 1
< Variable length data
Master = 2
< Master channel
VirtualMaster = 3
< Virtual master channel
Sync = 4
< Synchronize channel
MaxLength = 5
< Max length channel
VirtualData = 6
< Virtual data channel